LocationAccuracy enum

Location accuracy level; maps to Android accuracy constants.

Inheritance
Available extensions

Values

low → const LocationAccuracy

Coarse accuracy (e.g. network-based).

medium → const LocationAccuracy

Medium accuracy.

high → const LocationAccuracy

Fine accuracy (e.g. GPS).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LocationAccuracy>
A constant List of the values in this enum, in order of their declaration.