BackgroundLocationConfig class
Configuration for background location tracking.
Constructors
- BackgroundLocationConfig({int intervalMinutes = 1, LocationAccuracy accuracy = LocationAccuracy.high, String notificationChannelId = 'flutter_background_location_channel', String notificationTitle = 'Location tracking', String notificationBody = 'Recording your position.', int retentionDays = 0, int maxRecords = 0, String? databasePath})
-
const
Properties
- accuracy → LocationAccuracy
-
Location accuracy. Maps to Android accuracy constants.
final
- databasePath → String?
-
Optional custom database path. If null, plugin uses app support directory.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intervalMinutes → int
-
How often to record location (minutes). Default 1.
final
- maxRecords → int
-
Maximum number of records to keep. Oldest deleted first. 0 = unlimited.
final
- notificationBody → String
-
Notification body text.
final
- notificationChannelId → String
-
Notification channel id (Android). Must be set before starting.
final
- notificationTitle → String
-
Notification title shown while tracking.
final
- retentionDays → int
-
Keep only this many days of data. 0 = unlimited.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited