LocationRecord class
A single location record stored by the plugin.
Constructors
Properties
- accuracy → double?
-
Accuracy radius in meters, if available.
final
- altitude → double?
-
Altitude in meters, if available.
final
- bearing → double?
-
Bearing in degrees (0–360), if available.
final
- dateTime → DateTime
-
timestamp as a DateTime.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique row id in the database.
final
- latitude → double
-
Latitude in degrees.
final
- longitude → double
-
Longitude in degrees.
final
- provider → String?
-
Provider name (e.g. gps, network, fused), if available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
Session id for this tracking session, if available.
final
- speed → double?
-
Speed in m/s, if available.
final
- timestamp → int
-
Time when the location was recorded (milliseconds since epoch).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited